==> aio.api.github-0.0.1.tar.gz: aio.api.github-0.0.1/aio/api/github/api.py <==

from typing import Type

import gidgethub.abc

import abstracts

from .abstract import (
    AGithubAPI,
    AGithubCommit,
    AGithubIssue,
    AGithubIssues,
    AGithubIterator,
    AGithubLabel,
    AGithubRelease,
    AGithubRepo,
    AGithubTag)


@abstracts.implementer(AGithubCommit)
class GithubCommit:
    pass


@abstracts.implementer(AGithubIssue)
class GithubIssue:
    pass


@abstracts.implementer(AGithubIssues)
class GithubIssues:
    pass


@abstracts.implementer(AGithubIterator)
class GithubIterator:
    pass


@abstracts.implementer(AGithubLabel)
class GithubLabel:
    pass


@abstracts.implementer(AGithubRelease)
class GithubRelease:
    pass


@abstracts.implementer(AGithubRepo)
class GithubRepo:
    pass


@abstracts.implementer(AGithubTag)
class GithubTag:
    pass


@abstracts.implementer(AGithubAPI)
class GithubAPI:

    @property
    def api_class(self) -> Type[gidgethub.abc.GitHubAPI]:
        return super().api_class

    @property
    def commit_class(self) -> Type[AGithubCommit]:
        return GithubCommit

    @property
    def issue_class(self) -> Type[AGithubIssue]:
        return GithubIssue

    @property
    def issues_class(self) -> Type[AGithubIssues]:
        return GithubIssues

    @property
    def iterator_class(self) -> Type[AGithubIterator]:
        return GithubIterator

    @property
    def label_class(self) -> Type[AGithubLabel]:
        return GithubLabel

    @property
    def release_class(self) -> Type[AGithubRelease]:
        return GithubRelease

    @property
    def repo_class(self) -> Type[AGithubRepo]:
        return GithubRepo

    @property
    def tag_class(self) -> Type[AGithubTag]:
        return GithubTag

==> aio.api.github-0.2.4.tar.gz: aio.api.github-0.2.4/aio/api/github/api.py <==

from typing import Type

import gidgethub.aiohttp

import abstracts

from .abstract import (
    AGithubActions,
    AGithubAPI,
    AGithubCommit,
    AGithubIssue,
    AGithubIssues,
    AGithubIterator,
    AGithubLabel,
    AGithubRelease,
    AGithubReleaseAssets,
    AGithubRepo,
    AGithubTag,
    AGithubWorkflows)
from . import interface


@abstracts.implementer(AGithubActions)
class GithubActions:
    pass


@abstracts.implementer(AGithubWorkflows)
class GithubWorkflows:
    pass


@abstracts.implementer(AGithubCommit)
class GithubCommit:
    pass


@abstracts.implementer(AGithubIssue)
class GithubIssue:
    pass


@abstracts.implementer(AGithubIssues)
class GithubIssues:
    pass


@abstracts.implementer(AGithubIterator)
class GithubIterator:
    pass


@abstracts.implementer(AGithubLabel)
class GithubLabel:
    pass


@abstracts.implementer(AGithubRelease)
class GithubRelease:

    @property
    def assets_class(self) -> Type["interface.IGithubReleaseAssets"]:
        return GithubReleaseAssets


@abstracts.implementer(AGithubReleaseAssets)
class GithubReleaseAssets:
    pass


@abstracts.implementer(AGithubRepo)
class GithubRepo:
    pass


@abstracts.implementer(AGithubTag)
class GithubTag:
    pass


@abstracts.implementer(AGithubAPI)
class GithubAPI:

    def __init__(self, session, *args, **kwargs) -> None:
        AGithubAPI.__init__(self, session, *args, **kwargs)

    @property
    def actions_class(self) -> Type[AGithubActions]:
        return GithubActions

    @property
    def api_class(self) -> Type[gidgethub.aiohttp.GitHubAPI]:
        return super().api_class

    @property
    def commit_class(self) -> Type[AGithubCommit]:
        return GithubCommit

    @property
    def issue_class(self) -> Type[AGithubIssue]:
        return GithubIssue

    @property
    def issues_class(self) -> Type[AGithubIssues]:
        return GithubIssues

    @property
    def iterator_class(self) -> Type[AGithubIterator]:
        return GithubIterator

    @property
    def label_class(self) -> Type[AGithubLabel]:
        return GithubLabel

    @property
    def release_class(self) -> Type[AGithubRelease]:
        return GithubRelease

    @property
    def repo_class(self) -> Type[AGithubRepo]:
        return GithubRepo

    @property
    def tag_class(self) -> Type[AGithubTag]:
        return GithubTag

    @property
    def workflows_class(self) -> Type[AGithubWorkflows]:
        return GithubWorkflows
